@@ -1,12 +1,8 @@
+/* SPDX-License-Identifier: LGPL-2.1-or-later */
 /*
  * This file is part of libgpiod.
  *
- * Copyright (C) 2017-2018-2018 Bartosz Golaszewski <bartekgola@gmail.com>
- *
- * This program is free software; you can redistribute it and/or modify it
- * under the terms of the GNU Lesser General Public License as published by
- * the Free Software Foundation; either version 2.1 of the License, or (at
- * your option) any later version.
+ * Copyright (C) 2017-2018 Bartosz Golaszewski <bartekgola@gmail.com>
  */
 
 /* Common code for GPIO tools. */
@@ -54,9 +50,9 @@ void die_perror(const char *fmt, ...)
 
 void print_version(void)
 {
-	printf("%s (libgpiod) %s\n",
+	printf("%s (libgpiod) v%s\n",
 	       program_invocation_short_name, gpiod_version_string());
-	printf("Copyright (C) 2017-2018-2018 Bartosz Golaszewski\n");
+	printf("Copyright (C) 2017-2018 Bartosz Golaszewski\n");
 	printf("License: LGPLv2.1\n");
 	printf("This is free software: you are free to change and redistribute it.\n");
 	printf("There is NO WARRANTY, to the extent permitted by law.\n");
